@@ -1,5 +1,20 @@
 from .core import BasePattern, PatternModel, set_unit, ValidateResult
-from .main import type_parser, pattern_map, set_converter, set_converters, remove_converter, AnyOne, Bind
+from .main import (
+    type_parser,
+    pattern_map,
+    set_converter,
+    set_converters,
+    remove_converter,
+    AnyOne,
+    Bind,
+    NUMBER,
+    HEX,
+    HEX_COLOR,
+    EMAIL,
+    DATETIME,
+    IP,
+    URL,
+)
 from .base import UnionArg, SequenceArg, MappingArg
 from .util import Empty, AllParam, generic_isinstance
 from .exception import MatchFailed
